test_name "PE Dashboard Rake Tasks (legacy syntax)"

dashboard_hosts = hosts.select { |h| h['roles'].include? 'dashboard' }

step "Verify there's at least one dashboard host" do
  assert(dashboard_hosts.length > 0, "No dashboard hosts found!")
end

def build_rake_cmd_string(host, cmd)
  rake_path = host.is_pe? ? "/opt/puppet/bin/rake" : "rake"
  rakefile_path = host.is_pe? ? "/opt/puppet/share/puppet-dashboard/Rakefile" : "/usr/share/puppet-dashboard/Rakefile"
  "RAILS_ENV=production #{rake_path} -f #{rakefile_path} #{cmd}"
end

def run_rake_task(host, cmd)
  result = on(host, build_rake_cmd_string(host, cmd))
  result.stdout.split("\n")
end


#################################
# `defaultgroup` tasks
#################################


step "test defaultgroup:ensure_default_group rake task" do
  dashboard_hosts.each do |dashboard|
    run_rake_task(dashboard, "node:add name=foo.localdomain")
    run_rake_task(dashboard, "node:add name=bar.localdomain")

    run_rake_task(dashboard, "defaultgroup:ensure_default_group")

    results = run_rake_task(dashboard, "node:listgroups name=foo.localdomain")
    assert(results.include?("default"), "expected defaultgroup:ensure_default_group task to add group 'default'!  node:listgroups returned: #{results.join("\n")}")
    assert(results.include?("mcollective"), "expected defaultgroup:ensure_default_group task to add group 'mcollective'!  node:listgroups returned: #{results.join("\n")}")

    results = run_rake_task(dashboard, "node:listgroups name=bar.localdomain")
    assert(results.include?("default"), "expected defaultgroup:ensure_default_group task to add group 'default'!  node:listgroups returned: #{results.join("\n")}")
    assert(results.include?("mcollective"), "expected defaultgroup:ensure_default_group task to add group 'mcollective'!  node:listgroups returned: #{results.join("\n")}")

    # Make sure bar.localdomain is removed from mcollective when it is added to no mcollective

    run_rake_task(dashboard, "node:addgroup name=bar.localdomain group='no mcollective'")
    run_rake_task(dashboard, "defaultgroup:ensure_default_group")

    results = run_rake_task(dashboard, "node:listgroups name=foo.localdomain")
    assert(results.include?("default"), "expected defaultgroup:ensure_default_group task to add group 'default'!  node:listgroups returned: #{results.join("\n")}")
    assert(results.include?("mcollective"), "expected defaultgroup:ensure_default_group task to add group 'mcollective'!  node:listgroups returned: #{results.join("\n")}")

    results = run_rake_task(dashboard, "node:listgroups name=bar.localdomain")
    assert(results.include?("default"), "expected defaultgroup:ensure_default_group task to add group 'default'!  node:listgroups returned: #{results.join("\n")}")
    assert(!results.include?("mcollective"), "expected defaultgroup:ensure_default_group task to remove group 'mcollective'!  node:listgroups returned: #{results.join("\n")}")

    run_rake_task(dashboard, "node:del name=foo.localdomain")
    run_rake_task(dashboard, "node:del name=bar.localdomain")
  end
end

